@@ -2,6 +2,8 @@
 # Nebojsa Bozanic <bozanic@stanford.edu> Copyright 2020
 # Distributed under the BSD License
 
-def isi_profile(*args, **kwargs):
+import phasereset
+
+def test():
 
  return 0
\ No newline at end of file
